@@ -15,8 +15,8 @@ import platform
 import sys
 import traceback
 
-__all__ = ('MagickPixelPacket', 'c_magick_char_p', 'library', 'libc',
-           'libmagick', 'load_library')
+__all__ = ('MagickPixelPacket', 'PointInfo', 'AffineMatrix', 'c_magick_char_p',
+           'library', 'libc', 'libmagick', 'load_library')
 
 
 class c_magick_char_p(ctypes.c_char_p):
@@ -41,7 +41,7 @@ class c_magick_char_p(ctypes.c_char_p):
 
 def find_library(suffix=''):
     """Finds library path to try loading.  The result paths are not
-    guarenteed that they exist.
+    guaranteed that they exist.
 
     :param suffix: optional suffix e.g. ``'-Q16'``
     :type suffix: :class:`basestring`
@@ -129,6 +129,19 @@ class MagickPixelPacket(ctypes.Structure):
                 ('opacity', ctypes.c_double),
                 ('index', ctypes.c_double)]
 
+class PointInfo(ctypes.Structure):
+
+    _fields_ = [('x', ctypes.c_double),
+                ('y', ctypes.c_double)]
+
+class AffineMatrix(ctypes.Structure):
+    _fields_ = [('sx', ctypes.c_double),
+                ('rx', ctypes.c_double),
+                ('ry', ctypes.c_double),
+                ('sy', ctypes.c_double),
+                ('tx', ctypes.c_double),
+                ('ty', ctypes.c_double)]
+
 
 # Preserve the module itself even if it fails to import
 sys.modules['wand._api'] = sys.modules['wand.api']
@@ -217,7 +230,8 @@ try:
     library.MagickGetImageSignature.argtypes = [ctypes.c_void_p]
     library.MagickGetImageSignature.restype = c_magick_char_p
 
-    library.MagickGetImageProperty.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
+    library.MagickGetImageProperty.argtypes = [ctypes.c_void_p,
+                                               ctypes.c_char_p]
     library.MagickGetImageProperty.restype = c_magick_char_p
 
     library.MagickGetImageProperties.argtypes = [
@@ -227,7 +241,8 @@ try:
     ]
     library.MagickGetImageProperties.restype = ctypes.POINTER(ctypes.c_char_p)
 
-    library.MagickSetImageProperty.argtypes = [ctypes.c_void_p, ctypes.c_char_p,
+    library.MagickSetImageProperty.argtypes = [ctypes.c_void_p,
+                                               ctypes.c_char_p,
                                                ctypes.c_char_p]
 
     library.MagickDeleteImageProperty.argtypes = [ctypes.c_void_p,
@@ -283,7 +298,8 @@ try:
     library.MagickGetImageOrientation.argtypes = [ctypes.c_void_p]
     library.MagickGetImageOrientation.restype = ctypes.c_int
 
-    library.MagickSetImageOrientation.argtypes = [ctypes.c_void_p, ctypes.c_int]
+    library.MagickSetImageOrientation.argtypes = [ctypes.c_void_p,
+                                                  ctypes.c_int]
 
     library.MagickGetImageUnits.argtypes = [ctypes.c_void_p]
 
@@ -297,7 +313,8 @@ try:
     library.MagickGetImageCompression.argtypes = [ctypes.c_void_p]
     library.MagickGetImageCompression.restype = ctypes.c_int
 
-    library.MagickSetImageCompression.argtypes = [ctypes.c_void_p, ctypes.c_int]
+    library.MagickSetImageCompression.argtypes = [ctypes.c_void_p,
+                                                  ctypes.c_int]
 
     library.MagickGetImageDepth.argtypes = [ctypes.c_void_p]
     library.MagickGetImageDepth.restype = ctypes.c_size_t
@@ -385,8 +402,10 @@ try:
 
     library.PixelSetIteratorRow.argtypes = [ctypes.c_void_p, ctypes.c_ssize_t]
 
-    library.PixelGetNextIteratorRow.argtypes = [ctypes.c_void_p,
-                                                ctypes.POINTER(ctypes.c_size_t)]
+    library.PixelGetNextIteratorRow.argtypes = [
+        ctypes.c_void_p,
+        ctypes.POINTER(ctypes.c_size_t)
+    ]
     library.PixelGetNextIteratorRow.restype = ctypes.POINTER(ctypes.c_void_p)
 
     library.NewPixelWand.argtypes = []
@@ -586,8 +605,10 @@ try:
                                            ctypes.c_int]
     library.MagickSetAntialias.restype = ctypes.c_int
 
-    library.MagickGetImageHistogram.argtypes = [ctypes.c_void_p,
-                                                ctypes.POINTER(ctypes.c_size_t)]
+    library.MagickGetImageHistogram.argtypes = [
+        ctypes.c_void_p,
+        ctypes.POINTER(ctypes.c_size_t)
+    ]
     library.MagickGetImageHistogram.restype = ctypes.POINTER(ctypes.c_void_p)
 
     # These functions are const so it's okay for them to be c_char_p
@@ -597,7 +618,9 @@ try:
     libmagick.GetMagickReleaseDate.argtypes = []
     libmagick.GetMagickReleaseDate.restype = ctypes.c_char_p
 
-    libmagick.GetMagickQuantumDepth.argtypes = [ctypes.POINTER(ctypes.c_size_t)]
+    libmagick.GetMagickQuantumDepth.argtypes = [
+        ctypes.POINTER(ctypes.c_size_t)
+    ]
     libmagick.GetMagickQuantumDepth.restype = ctypes.c_char_p
 
     library.NewDrawingWand.restype = ctypes.c_void_p
@@ -618,18 +641,102 @@ try:
     library.DrawClearException.argtypes = [ctypes.c_void_p]
     library.DrawClearException.restype = ctypes.c_int
 
+    library.DrawAffine.argtypes = [ctypes.c_void_p, # Drawing wand
+                                   ctypes.POINTER(AffineMatrix)] # AffineMatrix
+
+    library.DrawComment.argtypes = [ctypes.c_void_p, # wand
+                                    ctypes.c_char_p] #comment
+
+    library.DrawComposite.argtypes = [ctypes.c_void_p, # DrawingWand wand
+                                      ctypes.c_int, # CompositeOperator
+                                      ctypes.c_double, # x
+                                      ctypes.c_double, # y
+                                      ctypes.c_double, # width
+                                      ctypes.c_double, # height
+                                      ctypes.c_void_p] # MagickWand wand
+    library.DrawComposite.restype = ctypes.c_uint
+
+    library.DrawSetBorderColor.argtypes = [ctypes.c_void_p, # wand
+                                           ctypes.c_void_p] # PixelWand color
+
+    library.DrawSetClipPath.argtypes = [ctypes.c_void_p, # wand
+                                        ctypes.c_char_p] # clip_mask
+    library.DrawSetClipPath.restype = ctypes.c_int
+
+    library.DrawSetClipRule.argtypes = [ctypes.c_void_p, # wand
+                                        ctypes.c_uint] # FillRule
+
+    library.DrawSetClipUnits.argtypes = [ctypes.c_void_p, # wand
+                                         ctypes.c_uint] # ClipPathUnits
+
     library.DrawSetFont.argtypes = [ctypes.c_void_p,
                                     ctypes.c_char_p]
 
+    library.DrawSetFontFamily.argtypes = [ctypes.c_void_p, # wand
+                                          ctypes.c_char_p] # font_family
+    library.DrawSetFontFamily.restype = ctypes.c_uint
+
+    library.DrawSetFontResolution.argtypes = [ctypes.c_void_p, #wand
+                                              ctypes.c_double, # x
+                                              ctypes.c_double] # y
+    library.DrawSetFontResolution.restype = ctypes.c_uint
+
     library.DrawSetFontSize.argtypes = [ctypes.c_void_p,
                                         ctypes.c_double]
 
+    library.DrawSetFontStretch.argtypes = [ctypes.c_void_p, # wand
+                                           ctypes.c_int] # font_stretch
+
+    library.DrawSetFontStyle.argtypes = [ctypes.c_void_p, # wand
+                                         ctypes.c_int] # style
+
+    library.DrawSetFontWeight.argtypes = [ctypes.c_void_p, # wand
+                                          ctypes.c_size_t] # font_weight
+
     library.DrawSetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
+    library.DrawSetFillOpacity.argtypes = [ctypes.c_void_p,
+                                           ctypes.c_double]
+
+    library.DrawSetFillPatternURL.argtypes = [ctypes.c_void_p, # wand
+                                              ctypes.c_char_p] # fill_url
+    library.DrawSetFillPatternURL.restype = ctypes.c_uint
+
+    library.DrawSetFillRule.argtypes = [ctypes.c_void_p,
+                                        ctypes.c_uint]
+
+    library.DrawSetOpacity.argtypes = [ctypes.c_void_p, ctypes.c_double]
+
+    library.DrawSetStrokeAntialias.argtypes = [ctypes.c_void_p, # wand
+                                               ctypes.c_int] # stroke_antialias
+
     library.DrawSetStrokeColor.argtypes = [ctypes.c_void_p,
                                            ctypes.c_void_p]
 
+    library.DrawSetStrokeDashArray.argtypes = [ctypes.c_void_p, # wand
+                                               ctypes.c_size_t, # number_elements
+                                               ctypes.POINTER(ctypes.c_double)]
+
+    library.DrawSetStrokeDashOffset.argtypes = [ctypes.c_void_p, # wand
+                                                ctypes.c_double] # dash_offset
+
+    library.DrawSetStrokeLineCap.argtypes = [ctypes.c_void_p, # wand
+                                             ctypes.c_int] # linecap
+
+    library.DrawSetStrokeLineJoin.argtypes = [ctypes.c_void_p, # wand
+                                              ctypes.c_int] # linejoin
+
+    library.DrawSetStrokeMiterLimit.argtypes = [ctypes.c_void_p, # wand
+                                                ctypes.c_size_t] # miterlimit
+
+    library.DrawSetStrokeOpacity.argtypes = [ctypes.c_void_p, # wand
+                                             ctypes.c_double] # stroke_opacity
+
+    library.DrawSetStrokePatternURL.argtypes = [ctypes.c_void_p, # wand
+                                              ctypes.c_char_p] # fill_url
+    library.DrawSetStrokePatternURL.restype = ctypes.c_uint
+
     library.DrawSetStrokeWidth.argtypes = [ctypes.c_void_p,
                                            ctypes.c_double]
 
@@ -642,6 +749,12 @@ try:
     library.DrawSetTextDecoration.argtypes = [ctypes.c_void_p,
                                               ctypes.c_int]
 
+    try:
+        library.DrawSetTextDirection.argtypes = [ctypes.c_void_p,
+                                                 ctypes.c_int]
+    except AttributeError:
+        library.DrawSetTextDirection = None
+
     library.DrawSetTextEncoding.argtypes = [ctypes.c_void_p,
                                             ctypes.c_char_p]
 
@@ -660,21 +773,94 @@ try:
     library.DrawSetTextUnderColor.argtypes = [ctypes.c_void_p,
                                               ctypes.c_void_p]
 
+    library.DrawSetVectorGraphics.argtypes = [ctypes.c_void_p,
+                                              ctypes.c_char_p]
+
+    library.DrawSetVectorGraphics.restype = ctypes.c_int
+
+    library.DrawResetVectorGraphics.argtypes = [ctypes.c_void_p]
+
+    library.DrawSetViewbox.argtypes = [ctypes.c_void_p, # wand
+                                       ctypes.c_ssize_t, # x1
+                                       ctypes.c_ssize_t, # y1
+                                       ctypes.c_ssize_t, # x2
+                                       ctypes.c_ssize_t] # y2
+
+    library.DrawGetBorderColor.argtypes = [ctypes.c_void_p, # wand
+                                           ctypes.c_void_p] # PixelWand color
+
+    library.DrawGetClipPath.argtypes = [ctypes.c_void_p]
+    library.DrawGetClipPath.restype = ctypes.c_void_p
+
+    library.DrawGetClipRule.argtypes = [ctypes.c_void_p]
+    library.DrawGetClipRule.restype = ctypes.c_uint
+
+    library.DrawGetClipUnits.argtypes = [ctypes.c_void_p]
+    library.DrawGetClipUnits.restype = ctypes.c_uint
+
     library.DrawGetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
+    library.DrawGetFillOpacity.argtypes = [ctypes.c_void_p]
+    library.DrawGetFillOpacity.restype = ctypes.c_double
+
+    library.DrawGetFillRule.argtypes = [ctypes.c_void_p]
+    library.DrawGetFillRule.restype =   ctypes.c_uint
+
+    library.DrawGetOpacity.argtypes = [ctypes.c_void_p]
+    library.DrawGetOpacity.restype = ctypes.c_double
+
+    library.DrawGetStrokeAntialias.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeAntialias.restype = ctypes.c_int
+
     library.DrawGetStrokeColor.argtypes = [ctypes.c_void_p,
                                            ctypes.c_void_p]
 
+    library.DrawGetStrokeDashArray.argtypes = [ctypes.c_void_p,
+                                      ctypes.POINTER(ctypes.c_size_t)]
+    library.DrawGetStrokeDashArray.restype = ctypes.POINTER(ctypes.c_double)
+
+    library.DrawGetStrokeDashOffset.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeDashOffset.restype = ctypes.c_double
+
+    library.DrawGetStrokeLineCap.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeLineCap.restype = ctypes.c_int
+
+    library.DrawGetStrokeLineJoin.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeLineJoin.restype = ctypes.c_int
+
+    library.DrawGetStrokeMiterLimit.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeMiterLimit.restype = ctypes.c_size_t
+
+    library.DrawGetStrokeOpacity.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeOpacity.restype = ctypes.c_double
+
     library.DrawGetStrokeWidth.argtypes = [ctypes.c_void_p]
     library.DrawGetStrokeWidth.restype = ctypes.c_double
 
     library.DrawGetFont.argtypes = [ctypes.c_void_p]
-    library.DrawGetFont.restype = ctypes.c_char_p
+    library.DrawGetFont.restype = ctypes.c_void_p
+
+    library.DrawGetFontFamily.argtypes = [ctypes.c_void_p]
+    library.DrawGetFontFamily.restype = ctypes.c_void_p
+
+    library.DrawGetFontResolution.argtypes = [ctypes.c_void_p, #wand
+                               ctypes.POINTER(ctypes.c_double), # x
+                               ctypes.POINTER(ctypes.c_double)] # y
+    library.DrawGetFontResolution.restype = ctypes.c_uint
 
     library.DrawGetFontSize.argtypes = [ctypes.c_void_p]
     library.DrawGetFontSize.restype = ctypes.c_double
 
+    library.DrawGetFontStyle.argtypes = [ctypes.c_void_p]
+    library.DrawGetFontStyle.restype = ctypes.c_int
+
+    library.DrawGetFontWeight.argtypes = [ctypes.c_void_p]
+    library.DrawGetFontWeight.restype = ctypes.c_size_t
+
+    library.DrawGetFontStretch.argtypes = [ctypes.c_void_p]
+    library.DrawGetFontStretch.restype = ctypes.c_int
+
     library.DrawGetTextAlignment.argtypes = [ctypes.c_void_p]
     library.DrawGetTextAlignment.restype = ctypes.c_int
 
@@ -684,8 +870,14 @@ try:
     library.DrawGetTextDecoration.argtypes = [ctypes.c_void_p]
     library.DrawGetTextDecoration.restype = ctypes.c_int
 
+    try:
+        library.DrawGetTextDirection.argtypes = [ctypes.c_void_p]
+        library.DrawGetTextDirection.restype = ctypes.c_int
+    except AttributeError:
+        library.DrawGetTextDirection = None
+
     library.DrawGetTextEncoding.argtypes = [ctypes.c_void_p]
-    library.DrawGetTextEncoding.restype = ctypes.c_char_p
+    library.DrawGetTextEncoding.restype = ctypes.c_void_p
 
     try:
         library.DrawGetTextInterlineSpacing.argtypes = [ctypes.c_void_p]
@@ -702,6 +894,9 @@ try:
     library.DrawGetTextUnderColor.argtypes = [ctypes.c_void_p,
                                               ctypes.c_void_p]
 
+    library.DrawGetVectorGraphics.argtypes = [ctypes.c_void_p]
+    library.DrawGetVectorGraphics.restype = ctypes.c_void_p
+
     library.DrawSetGravity.argtypes = [ctypes.c_void_p,
                                        ctypes.c_int]
 
@@ -722,22 +917,214 @@ try:
                                         ctypes.c_void_p]
     library.MagickDrawImage.restype = ctypes.c_int
 
+    library.DrawAnnotation.argtypes = [ctypes.c_void_p,
+                                       ctypes.c_double,
+                                       ctypes.c_double,
+                                       ctypes.POINTER(ctypes.c_ubyte)]
+
+    library.DrawArc.argtypes = [ctypes.c_void_p, # wand
+                                ctypes.c_double, # sx
+                                ctypes.c_double, # sy
+                                ctypes.c_double, # ex
+                                ctypes.c_double, # ey
+                                ctypes.c_double, # sd
+                                ctypes.c_double] # ed
+
+    library.DrawBezier.argtypes = [ctypes.c_void_p,
+                                   ctypes.c_ulong,
+                                   ctypes.POINTER(PointInfo)]
+
+    library.DrawCircle.argtypes = [ctypes.c_void_p, # wand
+                                   ctypes.c_double, # ox
+                                   ctypes.c_double, # oy
+                                   ctypes.c_double, # px
+                                   ctypes.c_double] # py
+
+    library.DrawColor.argtypes = [ctypes.c_void_p, # wand
+                                  ctypes.c_double, # x
+                                  ctypes.c_double, # y
+                                  ctypes.c_uint]   # PaintMethod
+
+    library.DrawEllipse.argtypes = [ctypes.c_void_p, # wand
+                                    ctypes.c_double, # ox
+                                    ctypes.c_double, # oy
+                                    ctypes.c_double, # rx
+                                    ctypes.c_double, # ry
+                                    ctypes.c_double, # start
+                                    ctypes.c_double] # end
+
     library.DrawLine.argtypes = [ctypes.c_void_p,
                                  ctypes.c_double,
                                  ctypes.c_double,
                                  ctypes.c_double,
                                  ctypes.c_double]
 
+    library.DrawMatte.argtypes = [ctypes.c_void_p, # wand
+                                  ctypes.c_double, # x
+                                  ctypes.c_double, # y
+                                  ctypes.c_uint]   # PaintMethod
+
+    library.DrawPathClose.argtypes = [ctypes.c_void_p] # wand
+
+    library.DrawPathCurveToAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                                ctypes.c_double, # x1
+                                                ctypes.c_double, # y1
+                                                ctypes.c_double, # x2
+                                                ctypes.c_double, # y2
+                                                ctypes.c_double, # x
+                                                ctypes.c_double] # y
+
+    library.DrawPathCurveToRelative.argtypes = [ctypes.c_void_p, # wand
+                                                ctypes.c_double, # x1
+                                                ctypes.c_double, # y1
+                                                ctypes.c_double, # x2
+                                                ctypes.c_double, # y2
+                                                ctypes.c_double, # x
+                                                ctypes.c_double] # y
+
+    library.DrawPathCurveToQuadraticBezierAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                                      ctypes.c_double, # x1
+                                                      ctypes.c_double, # y1
+                                                      ctypes.c_double, # x
+                                                      ctypes.c_double] # y
+
+    library.DrawPathCurveToQuadraticBezierRelative.argtypes = [ctypes.c_void_p, # wand
+                                                      ctypes.c_double, # x1
+                                                      ctypes.c_double, # y1
+                                                      ctypes.c_double, # x
+                                                      ctypes.c_double] # y
+
+    library.DrawPathCurveToQuadraticBezierSmoothAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                                      ctypes.c_double, # x
+                                                      ctypes.c_double] # y
+
+    library.DrawPathCurveToQuadraticBezierSmoothRelative.argtypes = [ctypes.c_void_p, # wand
+                                                      ctypes.c_double, # x
+                                                      ctypes.c_double] # y
+
+    library.DrawPathCurveToSmoothAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                                      ctypes.c_double, # x2
+                                                      ctypes.c_double, # y2
+                                                      ctypes.c_double, # x
+                                                      ctypes.c_double] # y
+
+    library.DrawPathCurveToSmoothRelative.argtypes = [ctypes.c_void_p, # wand
+                                                      ctypes.c_double, # x2
+                                                      ctypes.c_double, # y2
+                                                      ctypes.c_double, # x
+                                                      ctypes.c_double] # y
+
+    library.DrawPathEllipticArcAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                                    ctypes.c_double, # rx
+                                                    ctypes.c_double, # ry
+                                                    ctypes.c_double, # rotation
+                                                    ctypes.c_uint, # arc_flag
+                                                    ctypes.c_uint, # sweep_flag
+                                                    ctypes.c_double, # x
+                                                    ctypes.c_double] # y
+
+    library.DrawPathEllipticArcRelative.argtypes = [ctypes.c_void_p, # wand
+                                                    ctypes.c_double, # rx
+                                                    ctypes.c_double, # ry
+                                                    ctypes.c_double, # rotation
+                                                    ctypes.c_uint, # arc_flag
+                                                    ctypes.c_uint, # sweep_flag
+                                                    ctypes.c_double, # x
+                                                    ctypes.c_double] # y
+
+    library.DrawPathFinish.argtypes = [ctypes.c_void_p] # wand
+
+    library.DrawPathLineToAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                               ctypes.c_double, # x
+                                               ctypes.c_double] # y
+
+    library.DrawPathLineToRelative.argtypes = [ctypes.c_void_p, # wand
+                                               ctypes.c_double, # x
+                                               ctypes.c_double] # y
+
+    library.DrawPathLineToHorizontalAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                                         ctypes.c_double] # x
+
+    library.DrawPathLineToHorizontalRelative.argtypes = [ctypes.c_void_p, # wand
+                                                         ctypes.c_double] # x
+
+    library.DrawPathLineToVerticalAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                                       ctypes.c_double] # y
+
+    library.DrawPathLineToVerticalRelative.argtypes = [ctypes.c_void_p, # wand
+                                                       ctypes.c_double] # y
+
+    library.DrawPathMoveToAbsolute.argtypes = [ctypes.c_void_p, # wand
+                                               ctypes.c_double, # x
+                                               ctypes.c_double] # y
+
+    library.DrawPathMoveToRelative.argtypes = [ctypes.c_void_p, # wand
+                                               ctypes.c_double, # x
+                                               ctypes.c_double] # y
+
+    library.DrawPathStart.argtypes = [ctypes.c_void_p] # wand
+
+    library.DrawPoint.argtypes = [ctypes.c_void_p, # wand
+                                  ctypes.c_double, # x
+                                  ctypes.c_double] # y
+
+    library.DrawPolygon.argtypes = [ctypes.c_void_p,
+                                    ctypes.c_ulong,
+                                    ctypes.POINTER(PointInfo)]
+
+    library.DrawPolyline.argtypes = [ctypes.c_void_p,
+                                    ctypes.c_ulong,
+                                    ctypes.POINTER(PointInfo)]
+
+    library.DrawRotate.argtypes = [ctypes.c_void_p, # wand
+                                   ctypes.c_double] # degree
+
     library.DrawRectangle.argtypes = [ctypes.c_void_p,
                                       ctypes.c_double,
                                       ctypes.c_double,
                                       ctypes.c_double,
                                       ctypes.c_double]
 
-    library.DrawAnnotation.argtypes = [ctypes.c_void_p,
-                                       ctypes.c_double,
-                                       ctypes.c_double,
-                                       ctypes.POINTER(ctypes.c_ubyte)]
+    library.DrawRoundRectangle.argtypes = [ctypes.c_void_p, # wand
+                                           ctypes.c_double, # x1
+                                           ctypes.c_double, # y1
+                                           ctypes.c_double, # x2
+                                           ctypes.c_double, # y2
+                                           ctypes.c_double, # rx
+                                           ctypes.c_double] # ry
+
+    library.DrawScale.argtypes = [ctypes.c_void_p, # wand
+                                  ctypes.c_double, # x
+                                  ctypes.c_double] # y
+
+    library.DrawSkewX.argtypes = [ctypes.c_void_p, # wand
+                                  ctypes.c_double] # degree
+
+    library.DrawSkewY.argtypes = [ctypes.c_void_p, # wand
+                                  ctypes.c_double] # degree
+
+    library.DrawTranslate.argtypes = [ctypes.c_void_p, #wand
+                                      ctypes.c_double, # x
+                                      ctypes.c_double] # y
+
+### Drawing stack management ###
+    library.PushDrawingWand.argtypes = [ctypes.c_void_p]
+    library.PushDrawingWand.restype = ctypes.c_uint
+    library.DrawPushClipPath.argtypes = [ctypes.c_void_p, # wand
+                                         ctypes.c_char_p] # clip_mask_id
+    library.DrawPushDefs.argtypes = [ctypes.c_void_p]
+    library.DrawPushPattern.argtypes = [ctypes.c_void_p, # wand
+                                        ctypes.c_char_p, # clip_mask_id
+                                        ctypes.c_double, # x
+                                        ctypes.c_double, # y
+                                        ctypes.c_double, # width
+                                        ctypes.c_double] # height
+    library.DrawPushClipPath.restype = ctypes.c_uint
+    library.PopDrawingWand.argtypes = [ctypes.c_void_p]
+    library.PopDrawingWandrestype = ctypes.c_uint
+    library.DrawPopClipPath.argtypes = [ctypes.c_void_p]
+    library.DrawPopDefs.argtypes = [ctypes.c_void_p]
+    library.DrawPopPattern.argtypes = [ctypes.c_void_p]
 
     library.MagickNegateImage.argtypes = [ctypes.c_void_p, ctypes.c_int]
 
@@ -750,6 +1137,8 @@ try:
     library.MagickNormalizeImageChannel.argtypes = [ctypes.c_void_p,
                                                     ctypes.c_int]
 
+    library.MagickEqualizeImage.argtypes = [ctypes.c_void_p]
+
     library.MagickQueryFontMetrics.argtypes = [ctypes.c_void_p,
                                                ctypes.c_void_p,
                                                ctypes.c_char_p]
@@ -762,6 +1151,12 @@ try:
         ctypes.c_double
     )
 
+    library.MagickThresholdImage.argtypes = [ctypes.c_void_p, ctypes.c_double]
+
+    library.MagickThresholdImageChannel.argtypes = [ctypes.c_void_p,
+                                                    ctypes.c_int,
+                                                    ctypes.c_double]
+
     library.MagickModulateImage.argtypes = [ctypes.c_void_p,
                                             ctypes.c_double,
                                             ctypes.c_double,
@@ -788,4 +1183,3 @@ else:
     libc.fflush.argtypes = [ctypes.c_void_p]
 
 libc.free.argtypes = [ctypes.c_void_p]
-
